pub enum ModalPresentation {
Auto,
InTree,
NativeWindow,
}Expand description
How the framework should present a modal surface.
Variants
Auto
Let the framework pick the most appropriate backend for the runtime.
InTree
Present inside the current widget tree using the overlay system.
NativeWindow
Present in a separate native OS window.